@@ -37,7 +37,11 @@ __license__ = "Apache License, Version 2.0"
 from . import admin
 from . import captcha
 from . import csfr
+from . import opbeat
+from . import sematext
 
 from .admin import AdminPart
 from .captcha import CaptchaPart
 from .csfr import CSFRPart, csfr_protect, csfr_ensure
+from .opbeat import OpbeatPart
+from .sematext import SematextHandler, SematextPart
