@@ -97,24 +97,35 @@ class Account(base.Base):
         meta = "secret"
     )
 
+    confirmation_token = appier.field(
+        safe = True,
+        private = True,
+        meta = "secret"
+    )
+
     facebook_id = appier.field(
-        index = True
+        index = True,
+        safe = True
     )
 
     twitter_username = appier.field(
-        index = True
+        index = True,
+        safe = True
     )
 
     google_id = appier.field(
-        index = True
+        index = True,
+        safe = True
     )
 
     live_id = appier.field(
-        index = True
+        index = True,
+        safe = True
     )
 
     github_login = appier.field(
-        index = True
+        index = True,
+        safe = True
     )
 
     facebook_token = appier.field(
@@ -195,12 +206,14 @@ class Account(base.Base):
         return super(Account, cls).validate() + [
             appier.not_null("username"),
             appier.not_empty("username"),
+            appier.is_lower("username"),
             appier.string_gt("username", 3),
             appier.string_lt("username", 64),
             appier.not_duplicate("username", cls._name()),
 
             appier.not_null("email"),
             appier.not_empty("email"),
+            appier.is_lower("email"),
             appier.is_email("email"),
             appier.not_duplicate("email", cls._name()),
 
@@ -235,7 +248,12 @@ class Account(base.Base):
         ]
 
     @classmethod
-    def login(cls, username, password):
+    def login(cls, username, password, insensitive = True):
+        # in case the (case) insensitive option is enabled and the username
+        # is defined the value is converted to lower case so that a proper
+        # comparison may be used (not case sensitive)
+        if insensitive and username: username = username.lower()
+
         # verifies that both the provided username and password are valid
         # and that are correctly and properly defined (required for validation)
         if not username or not password:
@@ -320,7 +338,7 @@ class Account(base.Base):
         return account
 
     @classmethod
-    def recover(cls, identifier):
+    def recover(cls, identifier, send_email = False):
         # verifies if a valid identifier has been provided because that value
         # is required for the proper account recover process to be executed
         if not identifier:
@@ -354,14 +372,20 @@ class Account(base.Base):
 
         # runs the recover instance method that should generate a new reset token
         # for the account and send the proper notifications
-        return account.recover_s()
+        return account.recover_s(send_email = send_email)
 
     @classmethod
     def reset(cls, reset_token, password, password_confirm):
-        account = cls.validate_token(reset_token)
+        account = cls.validate_reset(reset_token)
         account.reset_s(password, password_confirm)
         return account
 
+    @classmethod
+    def confirm(cls, confirmation_token, send_email = False):
+        account = cls.validate_confirmation(confirmation_token)
+        account.confirm_s(send_email = send_email)
+        return account
+
     @classmethod
     def verify(cls, encoded, decoded):
         type, salt, digest, plain = cls.unpack(encoded)
@@ -400,11 +424,17 @@ class Account(base.Base):
         return (type, salt, digest, plain)
 
     @classmethod
-    def validate_token(cls, reset_token):
+    def validate_reset(cls, reset_token):
         account = cls.get(reset_token = reset_token, raise_e = False)
         if account: return account
         raise appier.SecurityError(message = "Invalid reset token")
 
+    @classmethod
+    def validate_confirmation(cls, confirmation_token):
+        account = cls.get(confirmation_token = confirmation_token, raise_e = False)
+        if account: return account
+        raise appier.SecurityError(message = "Invalid confirmation token")
+
     @classmethod
     def from_session(cls, *args, **kwargs):
         session = appier.get_session()
@@ -464,25 +494,33 @@ class Account(base.Base):
             if not is_removable: continue
             delete(key)
 
+    def pre_validate(self):
+        base.Base.pre_validate(self)
+        if hasattr(self, "username") and self.username:
+            self.username = self.username.lower()
+        if hasattr(self, "email") and self.email:
+            self.email = self.email.lower()
+
     def pre_create(self):
         base.Base.pre_create(self)
         self.key = self.secret()
+        self.confirmation_token = self.secret()
 
     def pre_save(self):
         base.Base.pre_save(self)
         if hasattr(self, "password") and self.password:
             self.password = self.encrypt(self.password)
 
-    def touch_s(self):
-        # updates the last login of the account with the current timestamp
-        # and saves the account so that this value is persisted
-        self.last_login = time.time()
+    def confirm_s(self, send_email = False):
+        self.confirmation_token = None
+        self.enabled = True
+        if send_email: self.email_confirm()
         self.save()
 
-    def recover_s(self):
+    def recover_s(self, send_email = False):
         self.reset_token = self.secret()
         self.save()
-        self.email_recover()
+        if send_email: self.email_recover()
         return self.reset_token
 
     def reset_s(self, password, password_confirm):
@@ -523,6 +561,13 @@ class Account(base.Base):
         if not self.username: return self.email
         return "%s <%s>" % (self.username, self.email)
 
+    @appier.operation(name = "Touch")
+    def touch_s(self):
+        # updates the last login of the account with the current timestamp
+        # and saves the account so that this value is persisted
+        self.last_login = time.time()
+        self.save()
+
     @appier.operation(name = "Generate Key")
     def generate_key_s(self, force = False):
         self = self.reload(rules = False)
@@ -530,10 +575,16 @@ class Account(base.Base):
         self.key = self.secret()
         self.save()
 
+    @appier.operation(name = "Mark Unconfirmed")
+    def mark_unconfirmed_s(self, owner = None):
+        self.enabled = False
+        self.confirmation_token = self.secret()
+        self.save()
+
     @appier.operation(name = "Email New")
     def email_new(self, password = None, owner = None):
         owner = owner or appier.get_app()
-        account = self.reload(meta = True)
+        account = self.reload(rules = False, meta = True)
         base.Base.send_email_g(
             owner,
             "admin/email/account/new.html.tpl",
@@ -544,6 +595,19 @@ class Account(base.Base):
             account_password = password
         )
 
+    @appier.operation(name = "Email Confirm")
+    def email_confirm(self, owner = None):
+        owner = owner or appier.get_app()
+        account = self.reload(rules = False, meta = True)
+        base.Base.send_email_g(
+            owner,
+            "admin/email/account/confirm.html.tpl",
+            receivers = [self.email_f],
+            subject = "Confirm account",
+            title = "Confirm account",
+            account = account
+        )
+
     @appier.operation(name = "Email Recover")
     def email_recover(self, owner = None):
         owner = owner or appier.get_app()
@@ -557,6 +621,10 @@ class Account(base.Base):
             account = account
         )
 
+    @property
+    def confirmed(self):
+        return self.enabled
+
     def _set_session(self, unset = True, safes = [], method = "set"):
         cls = self.__class__
         if unset: cls._unset_session(safes = safes)
