@@ -104,6 +104,8 @@ class AdminPart(
         self.owner.lib_loaders["jinja2"] = self._jinja2_loader
         self.owner.lib_loaders["ssl"] = self._ssl_loader
 
+        if self.owner.allow_headers: self.owner.allow_headers += ", X-Secret-Key"
+
         self.logger.debug("Generating admin interfaces ...")
         for model_c in self.models_r:
             if not model_c.is_attached(): continue
@@ -127,6 +129,7 @@ class AdminPart(
             (("GET",), "/admin/operations", self.operations),
             (("GET",), "/admin/routes", self.list_routes),
             (("GET",), "/admin/configs", self.list_configs),
+            (("GET",), "/admin/parts", self.list_parts),
             (("GET",), "/admin/libraries", self.list_libraries),
             (("GET",), "/admin/operations/build_index", self.build_index),
             (("GET",), "/admin/operations/test_email", self.test_email),
@@ -468,6 +471,16 @@ class AdminPart(
             configs = configs
         )
 
+    @appier.ensure(token = "admin")
+    def list_parts(self):
+        app = appier.get_app()
+        parts = app.get_parts()
+        return self.template(
+            "parts.html.tpl",
+            section = "status",
+            parts = parts
+        )
+
     @appier.ensure(token = "admin")
     def list_libraries(self):
         app = appier.get_app()
