@@ -49,7 +49,7 @@ class CSFRPart(appier.Part):
     Should be used with proper knowledge of the inner workings of
     the captcha mechanism to avoid any security problems.
 
-    @see: http://en.wikipedia.org/wiki/Cross-site_request_forgery
+    :see: http://en.wikipedia.org/wiki/Cross-site_request_forgery
     """
 
     def load(self):
@@ -60,7 +60,7 @@ class CSFRPart(appier.Part):
 
     def csfr(self, scope = None, name = "csfr_token"):
         token = self._gen_token(scope = scope)
-        return self.owner.escape_jinja(
+        return self.owner.escape_template(
             "<input type=\"hidden\" name=\"%s\" value=\"%s\"/>" %\
             (name, token)
         )
